.. currentmodule:: sardana.pool.poolcountertimer

.. _sardana-countertimer-api:

=============================
Counter/Timer API reference
=============================

.. todo:: document Counter/Timer API reference

.. seealso:: 
    
    :ref:`sardana-countertimer-overview`
        the counter/timer overview 
    
    :class:`~sardana.tango.pool.CTExpChannel.CTExpChannel`
        the counter/timer tango device :term:`API`

..    :class:`~sardana.pool.poolcountertimer.PoolCounterTimer`
..        the counter/timer class :term:`API`
